@@ -24,8 +24,8 @@ class Renderer:
         # TODO: handle AA
         mask_img = (mask_img
                     .convert('L')
-                    .resize((self.input_space.arr_y_resolution,
-                             self.input_space.arr_x_resolution)))
+                    .resize((self.input_space.arr_x_resolution,
+                             self.input_space.arr_y_resolution)))
         mask_arr = np.array(mask_img, dtype=np.float32)
         mask_arr = gaussian(mask_arr, sigma=7)
         mask_noise = 1 + np.random.random(mask_arr.shape) * 0.02
